/*
* ============================================================================
*  Name        : mccexappnwsettingslist.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppNwSettingsList declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPNWSETTINGSLIST_H
#define C_CMCCEXAPPNWSETTINGSLIST_H

#include <aknsettingitemlist.h>

class CMccExAppNwSettings;

/**
 * CMccExAppNwSettingsList implements the network setting item list control.
 * It encapsulates all the needed functionality to edit, update and save
 * the setting data related to MCC example application network settings.
 */
class CMccExAppNwSettingsList : public CAknSettingItemList
    {
public:
    
    /**
     * Two-phased constructor.
     * 
     * @return Pointer to newly created CMccExAppNwSettingsList object.
     */
    static CMccExAppNwSettingsList* NewL( CMccExAppNwSettings& aSettings );
    
    /**
     * Two-phased constructor. Leaves the created object to cleanup stack.
     * 
     * @return Pointer to newly created CMccExAppNwSettingsList object.
     */
    static CMccExAppNwSettingsList* NewLC( CMccExAppNwSettings& aSettings );
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppNwSettingsList();

public:
    
    /**
     * Used to change the selected item. Called by CMccExAppNwSettingsView.
     * 
     * @see CMccExAppNwSettingsView.
     */
    void ChangeSelectedItemL();
    
protected:
    
// From CAknSettingItemList
    
    /**
     * From CAknSettingItemList.
     * Factory function for creating a setting item matching the given ID.
     * 
     * @see CAknSettingItemList
     * @param aSettingId ID of the setting to be created.
     */
    CAknSettingItem* CreateSettingItemL( TInt aSettingId );
    
// From CCoeControl
    
    /**
     * From CCoeControl.
     * Size changed.
     * 
     * @see CCoeControl.
     */
    void SizeChanged();
    
private:
    
    /**
     * C++ constructor.
     */
    CMccExAppNwSettingsList( CMccExAppNwSettings& aSettings );
    
private:    // Data
    
    /**
     * Settings storage.
     */
    CMccExAppNwSettings& iSettings;
    
    };

#endif // C_CMCCEXAPPNWSETTINGSLIST_H
