/*
* ============================================================================
*  Name        : mccexappnwsettingsview.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppNwSettingsView declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPNWSETTINGSVIEW_H
#define C_CMCCEXAPPNWSETTINGSVIEW_H

#include "mccexappviewbase.h"

class CMccExAppNwSettings;
class CMccExEngine;

/**
 * Class CMccExAppNwSettingsView is used to edit network settings such as
 * remote address, port and so forth in MCC example.
 */
class CMccExAppNwSettingsView : public CMccExAppViewBase
    {
public:
    
// Constructors and destructor.
    
    /**
     * Two-phased constructor.
     * 
     * @return Pointer to a CMccExAppNwSettingsView object.
     */
    static CMccExAppNwSettingsView* NewL( CMccExEngine& aEngine );
    
    /**
     * Two-phased constructor. Leaves the created object into cleanup stack.
     * 
     * @return Pointer to a CMccExAppNwSettingsView object.
     */
    static CMccExAppNwSettingsView* NewLC( CMccExEngine& aEngine );
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppNwSettingsView();

// from CAknView
    
    /**
     * From CAknView.
     * View specific command handling.
     * 
     * @see CAknView.
     * @param aCommand ID of the command.
     */
    void HandleCommandL( TInt aCommand );
    
protected:
    
// From CMccExAppViewBase
    
    /**
     * From CMccExAppViewBase.
     * Factory function for creating the compound control.
     * 
     * @see CMccExAppViewBase.
     * @return Compound control.
     */
    CCoeControl* CreateContainerL();
    
private:
    
    /**
     * C++ default constructor.
     */
    CMccExAppNwSettingsView( CMccExEngine& aEngine );
    
    /**
     * Symbian 2nd phase constructor.
     */
    void ConstructL();
    
// New functions
    
    /**
     * Helper function to handle a setting item change.
     */
    void DoChangeSettingL();
    
    /**
     * Helper function to handle saving of the network settings.
     */
    void DoSaveSettingsL();
    
private:    // Data
    
    /**
     * Settings datastorage.
     * Own.
     */
    CMccExAppNwSettings* iSettings;
    
    };

#endif // C_CMCCEXAPPNWSETTINGSVIEW_H
