/*
* ============================================================================
*  Name        : streamstateprepared.h
*  Part of     : mccexample / mccexengine
*  Description : CStreamStatePrepared declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CSTREAMSTATEPREPARED_H
#define C_CSTREAMSTATEPREPARED_H

// INCLUDES
#include "streamstatebase.h"

// CLASS DECLARATION

/**
 * CStreamStatePrepared implements prepared state in the MCC example stream
 * state machine.
 */
NONSHARABLE_CLASS( CStreamStatePrepared ) : public CStreamStateBase
    {
public:

    /**
     * Destructor.
     */
    virtual ~CStreamStatePrepared();

    /**
     * Two-phased constructor.
     */
    static CStreamStatePrepared* NewL();

    /**
     * Two-phased constructor. Leaves the created instance into the cleanup
     * stack.
     */
    static CStreamStatePrepared* NewLC();

// from CStreamStateBase
    
    /**
     * From CStreamStateBase.
     * Returns the TControlState of this state.
     * 
     * @see CStreamStateBase
     * @see TControlState
     */
    TControlState ControlState() const;
    
    /**
     * From CStreamStateBase.
     * Handles the MCC event associated for this state.
     * 
     * @see CStreamStateBase
     * @see TMccEvent
     */
    void HandleMccEvent( const TMccEvent& aEvent, CStreamBase& aStream );
    
protected:
    
// From CStreamStateBase
    
    /**
     * From CStreamStateBase.
     * Called when entering this state.
     * 
     * @see CStreamStateBase::EnterStateL
     */
    void DoEnterStateL( CStreamBase& aStream,
            const CStreamStateBase& aPrevState );
    
private:
    
    /**
     * Constructor for performing 1st stage construction.
     */
    CStreamStatePrepared();

    /**
     * Symbian default constructor for performing 2nd stage construction.
     */
    void ConstructL();

    };

#endif  // C_CSTREAMSTATEPREPARED_H
