/*
* ============================================================================
*  Name        : videostreambase.h
*  Part of     : mccexample / mccexengine
*  Description : CVideoStreamBase declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CVIDEOSTREAMBASE_H
#define C_CVIDEOSTREAMBASE_H

#include <e32base.h>

#include "streambase.h"

class CMccInterface;
class CMccCodecInformation;
class CStreamStateMachine;

// CONSTANTS
// Video & audio default payload types
const TUint KVideoPayloadType = 97;
const TUint KAudioPayloadType = 96;

/**
 * CVideoStreamBase provides a base class for up- and downlink video streams.
 */
NONSHARABLE_CLASS( CVideoStreamBase ) : public CStreamBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CVideoStreamBase();
    
protected:
    
    /**
     * Constructor for performing 1st stage construction.
     * 
     * @param aStateMachine Statemachine for this stream.
     * @param aMcc MCC instance for this stream.
     * @param aSession ID of the session in which this stream will belong.
     * @param aLink ID of the link in which this stream will belong.
     */
    CVideoStreamBase( CStreamStateMachine& aStateMachine,
            CMccInterface& aMcc, TUint32 aSession, TUint32 aLink );
    
    /**
     * Symbian default constructor for performing 2nd stage construction.
     * 
     * @see mmccinterfacedef.h For different stream types.
     * @see streambase.h For further information on possible leave codes.
     * @leave KErrArgument If the specified aType is other than
     *        KMccVideoDownlinkStream or KMccVideoUplinkStream.
     * @param aCodec Codec to be used in this stream.
     * @param aType Type of this stream.
     */
    virtual void ConstructL( CMccCodecInformation& aCodec, TInt aType );
    
    };

#endif  // C_CVIDEOSTREAMBASE_H
