/*
* ============================================================================
*  Name        : mccexenginecamerainfo.cpp
*  Part of     : mccexample / mccexengine
*  Description : CMccExEngineCameraInfo class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <e32debug.h>

#include "mccexenginecamerainfo.h"

// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::CMccExEngineCameraInfo
// ---------------------------------------------------------------------------
//
CMccExEngineCameraInfo::CMccExEngineCameraInfo( TInt aCamIndex ) :
    iCameraIndex( aCamIndex )
    {
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::~CMccExEngineCameraInfo
// ---------------------------------------------------------------------------
//
CMccExEngineCameraInfo::~CMccExEngineCameraInfo()
    {
    delete iCamera;
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::NewLC
// ---------------------------------------------------------------------------
//
CMccExEngineCameraInfo* CMccExEngineCameraInfo::NewLC( TInt aCamIndex )
    {
    CMccExEngineCameraInfo* self =
        new ( ELeave ) CMccExEngineCameraInfo( aCamIndex );
    CleanupStack::PushL( self );
    self->ConstructL();
    return self;
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::NewL
// ---------------------------------------------------------------------------
//
CMccExEngineCameraInfo* CMccExEngineCameraInfo::NewL( TInt aCamIndex )
    {
    CMccExEngineCameraInfo* self = CMccExEngineCameraInfo::NewLC( aCamIndex );
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::CamerasAvailable
// ---------------------------------------------------------------------------
//
TInt CMccExEngineCameraInfo::CamerasAvailable()
    {
    return CCamera::CamerasAvailable();
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::VideoFrameSizesL
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::VideoFrameSizesL( RArray<TSize>& aSizes )
    {
    TCameraInfo info;
    iCamera->CameraInfo( info );
    RDebug::Print( _L("VideoFrameSizesL: orient: %d"), info.iOrientation );
    const TInt sizes( info.iNumVideoFrameSizesSupported );
    const CCamera::TFormat fmtSupp(
        static_cast<CCamera::TFormat>( info.iVideoFrameFormatsSupported ) );
    
    aSizes.Reset();
    for( TInt k = 0; k < sizes; k++ )
        {
        TSize size;
        iCamera->EnumerateVideoFrameSizes( size, k, fmtSupp );
        aSizes.AppendL( size );
        
        RDebug::Print( _L( "VideoFrameSizesL Cam: %d (%d) %dx%d (h x w)" ),
            iCameraIndex, k, size.iHeight, size.iWidth );
        }
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::CameraInformation
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::CameraInformation( TCameraInfo& aInfo )
    {
    iCamera->CameraInfo( aInfo );
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::HandleEvent
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::HandleEvent( const TECAMEvent& /*aEvent*/ )
    {
    
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::ViewFinderReady
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::ViewFinderReady(
    MCameraBuffer& /*aCameraBuffer*/, TInt /*aError*/ )
    {
    
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::ImageBufferReady
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::ImageBufferReady(
    MCameraBuffer& /*aCameraBuffer*/, TInt /*aError*/ )
    {
    
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::VideoBufferReady
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::VideoBufferReady(
    MCameraBuffer& /*aCameraBuffer*/, TInt /*aError*/ )
    {
    
    }


// ---------------------------------------------------------------------------
// CMccExEngineCameraInfo::ConstructL
// ---------------------------------------------------------------------------
//
void CMccExEngineCameraInfo::ConstructL()
    {
    iCamera = CCamera::New2L( *this, iCameraIndex, 0 );
    }
