/*
* ============================================================================
*  Name        : streamstatepaused.cpp
*  Part of     : mccexample / mccexengine
*  Description : CStreamStatePaused class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccevents.h>
#include <mmccinterface.h>
#include <e32debug.h>

#include "streambase.h"
#include "streamstatepaused.h"
#include "streamstateactive.h"
#include "mccexpanic.pan"

// ======== MEMBER FUNCTIONS ========


// ---------------------------------------------------------------------------
// CStreamStatePaused::CStreamStatePaused
// ---------------------------------------------------------------------------
//
CStreamStatePaused::CStreamStatePaused() : CStreamStateBase()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::~CStreamStatePaused
// ---------------------------------------------------------------------------
//
CStreamStatePaused::~CStreamStatePaused()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::NewLC
// ---------------------------------------------------------------------------
//
CStreamStatePaused* CStreamStatePaused::NewLC()
    {
    CStreamStatePaused* self = new ( ELeave ) CStreamStatePaused();
    CleanupStack::PushL( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::NewL
// ---------------------------------------------------------------------------
//
CStreamStatePaused* CStreamStatePaused::NewL()
    {
    CStreamStatePaused* self = CStreamStatePaused::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::ControlState
// ---------------------------------------------------------------------------
//
TControlState CStreamStatePaused::ControlState() const
    {
    return EStatePaused;
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::HandleMccEvent
// ---------------------------------------------------------------------------
//
void CStreamStatePaused::HandleMccEvent( const TMccEvent& aEvent,
    CStreamBase& aStream )
    {
    RDebug::Print( _L( "CStreamStatePaused got eventtype: %u" ),
            aEvent.iEventType );
    
    switch( aEvent.iEventType )
        {
        // The stream may send also 'buffering' or 'idle' event when it starts
        // the state change towards paused state. This especially applies to
        // downlink stream where the end of RX data may happen before we
        // explicitly ask it to pause.
        case KMccStreamPaused:
            {
            CStreamStateBase::HandleMccEvent( aEvent, aStream );
            }
            break;
        case KMccStreamIdle:
            break;
        default:
            MccExPanic( EMccExEventType );
            break;
        }
    }


// ---------------------------------------------------------------------------
// CStreamStatePaused::DoEnterStateL
// ---------------------------------------------------------------------------
//
void CStreamStatePaused::DoEnterStateL( CStreamBase& aStream,
    const CStreamStateBase& aPrevState )
    {
    // Assert that state transition obeys the rules.
    __ASSERT_ALWAYS( EStateStarted == aPrevState.ControlState(),
            User::Leave( KErrArgument ) );
    
    const TUint32 session( aStream.SessionId() );
    const TUint32 link( aStream.LinkId() );
    const TUint32 stream( aStream.StreamId() );
    const TBool rtcp( aStream.RtcpUsage() );
    
    User::LeaveIfError( aStream.MccInterface().PauseStream(
                    session, link, stream, 0, rtcp ) );
    }

