/*
* ============================================================================
*  Name        : streamstateprepared.cpp
*  Part of     : mccexample / mccexengine
*  Description : CStreamStatePrepared class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccinterface.h>
#include <mmccevents.h>
#include <e32debug.h>

#include "streamstateprepared.h"
#include "streambase.h"
#include "mccexpanic.pan"

// ======== MEMBER FUNCTIONS ========


// ---------------------------------------------------------------------------
// CStreamStatePrepared::CStreamStatePrepared
// ---------------------------------------------------------------------------
//
CStreamStatePrepared::CStreamStatePrepared() : CStreamStateBase()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::~CStreamStatePrepared
// ---------------------------------------------------------------------------
//
CStreamStatePrepared::~CStreamStatePrepared()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::NewLC
// ---------------------------------------------------------------------------
//
CStreamStatePrepared* CStreamStatePrepared::NewLC()
    {
    CStreamStatePrepared* self = new ( ELeave ) CStreamStatePrepared();
    CleanupStack::PushL( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::NewL
// ---------------------------------------------------------------------------
//
CStreamStatePrepared* CStreamStatePrepared::NewL()
    {
    CStreamStatePrepared* self = CStreamStatePrepared::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::ControlState
// ---------------------------------------------------------------------------
//
TControlState CStreamStatePrepared::ControlState() const
    {
    return EStatePrepared;
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::HandleMccEvent
// ---------------------------------------------------------------------------
//
void CStreamStatePrepared::HandleMccEvent( const TMccEvent& aEvent,
    CStreamBase& aStream )
    {
    RDebug::Print( _L( "CStreamStatePrepared got eventtype: %u" ),
            aEvent.iEventType );
    
    switch( aEvent.iEventType )
        {
        case KMccStreamPrepared:
            CStreamStateBase::HandleMccEvent( aEvent, aStream );
            break;
        case KMccStreamStopped:
            break;
        default:
            MccExPanic( EMccExEventType );
            break;
        }
    }


// ---------------------------------------------------------------------------
// CStreamStatePrepared::DoEnterStateL
// ---------------------------------------------------------------------------
//
void CStreamStatePrepared::DoEnterStateL( CStreamBase& aStream,
    const CStreamStateBase& aPrevState )
    {
    // Assert that state transition obeys the rules.
    __ASSERT_ALWAYS( EStateStopped == aPrevState.ControlState(),
            User::Leave( KErrArgument ) );
    
    const TUint32 session( aStream.SessionId() );
    const TUint32 link( aStream.LinkId() );
    const TUint32 stream( aStream.StreamId() );
    
    User::LeaveIfError(
            aStream.MccInterface().PrepareStream( session, link, stream ) );
    }
