/*
* ============================================================================
*  Name        : streamstatestopped.cpp
*  Part of     : mccexample / mccexengine
*  Description : CStreamStateStopped class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccinterface.h>
#include <mmccevents.h>
#include <e32debug.h>

#include "streambase.h"
#include "streamstatestopped.h"
#include "mccexpanic.pan"

// ======== MEMBER FUNCTIONS ========


// ---------------------------------------------------------------------------
// CStreamStateStopped::CStreamStateStopped
// ---------------------------------------------------------------------------
//
CStreamStateStopped::CStreamStateStopped() : CStreamStateBase()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::~CStreamStateStopped
// ---------------------------------------------------------------------------
//
CStreamStateStopped::~CStreamStateStopped()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::NewLC
// ---------------------------------------------------------------------------
//
CStreamStateStopped* CStreamStateStopped::NewLC()
    {
    CStreamStateStopped* self = new ( ELeave ) CStreamStateStopped();
    CleanupStack::PushL( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::NewL
// ---------------------------------------------------------------------------
//
CStreamStateStopped* CStreamStateStopped::NewL()
    {
    CStreamStateStopped* self = CStreamStateStopped::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::ControlState
// ---------------------------------------------------------------------------
//
TControlState CStreamStateStopped::ControlState() const
    {
    return EStateStopped;
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::::HandleMccEvent
// ---------------------------------------------------------------------------
//
void CStreamStateStopped::HandleMccEvent( const TMccEvent& aEvent,
    CStreamBase& aStream )
    {
    RDebug::Print( _L( "CStreamStateStopped got eventtype: %u" ),
            aEvent.iEventType );
    
    switch( aEvent.iEventType )
        {
        case KMccStreamStopped:
            CStreamStateBase::HandleMccEvent( aEvent, aStream );
            break;
        case KMccStreamIdle:
            break;
        default:
            MccExPanic( EMccExEventType );
            break;
        }
    }


// ---------------------------------------------------------------------------
// CStreamStateStopped::DoEnterStateL
// ---------------------------------------------------------------------------
//
void CStreamStateStopped::DoEnterStateL( CStreamBase& aStream,
    const CStreamStateBase& aPrevState )
    {
    const TUint32 session( aStream.SessionId() );
    const TUint32 link( aStream.LinkId() );
    const TUint32 stream( aStream.StreamId() );
    
    // Stop only from a more active state than 'stopped'. This avoids a
    // KERN-EXEC 3 panic in MCC RTP datasink due to a NULL ptr access.
    if ( EStateStopped != aPrevState.ControlState() )
        {
        User::LeaveIfError( aStream.MccInterface().StopStream(
                session, link, stream ) );
        }
    }
